
From: Lennert Buytenhek <buytenh@wantstofly.org>

IXP2000 (ARM-based) platforms use a separate 'struct resource' for PCI MEM
space.  Resource allocation for PCI BARs always fails because the 'root'
resource (the IXP2000 PCI MEM resource) always has the entire address space
(00000000-ffffffff) free, and find_resource() calculates the size of that
range as ffffffff-00000000+1=0, so all allocations fail because it thinks
there is no space.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/kernel/resource.c |    2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)

diff -puN kernel/resource.c~pci-enumeration-on-ixp2000-overflow-in-kernel-resourcec kernel/resource.c
--- 25/kernel/resource.c~pci-enumeration-on-ixp2000-overflow-in-kernel-resourcec	2005-04-10 15:07:52.000000000 -0700
+++ 25-akpm/kernel/resource.c	2005-04-10 15:07:52.000000000 -0700
@@ -266,7 +266,7 @@ static int find_resource(struct resource
 		new->start = (new->start + align - 1) & ~(align - 1);
 		if (alignf)
 			alignf(alignf_data, new, size, align);
-		if (new->start < new->end && new->end - new->start + 1 >= size) {
+		if (new->start < new->end && new->end - new->start >= size - 1) {
 			new->end = new->start + size - 1;
 			return 0;
 		}
_
